@@ -12,6 +12,7 @@ from ..utils import (
 
 
 class SendtoNewsIE(InfoExtractor):
+    _WORKING = False
     _VALID_URL = r'https?://embed\.sendtonews\.com/player2/embedplayer\.php\?.*\bSC=(?P<id>[0-9A-Za-z-]+)'
 
     _TEST = {
@@ -77,9 +78,6 @@ class SendtoNewsIE(InfoExtractor):
                     'format_id': '%s-%d' % (determine_protocol(f), tbr),
                     'tbr': tbr,
                 })
-            # 'tbr' was explicitly set to be preferred over 'height' originally,
-            # So this is being kept unless someone can confirm this is unnecessary
-            self._sort_formats(info_dict['formats'], ('tbr', 'res'))
 
             thumbnails = []
             if video.get('thumbnailUrl'):
@@ -98,6 +96,9 @@ class SendtoNewsIE(InfoExtractor):
                 'thumbnails': thumbnails,
                 'duration': float_or_none(video.get('SM_length')),
                 'timestamp': parse_iso8601(video.get('S_sysDate'), delimiter=' '),
+                # 'tbr' was explicitly set to be preferred over 'height' originally,
+                # So this is being kept unless someone can confirm this is unnecessary
+                '_format_sort_fields': ('tbr', 'res')
             })
             entries.append(info_dict)
 
