@@ -2,9 +2,10 @@ import re
 
 from .common import InfoExtractor
 from ..utils import (
-    extract_attributes,
     ExtractorError,
+    extract_attributes,
     get_element_by_class,
+    str_or_none,
 )
 
 
@@ -30,7 +31,6 @@ class SteamIE(InfoExtractor):
                     'ext': 'mp4',
                     'title': 'Terraria video 256785003',
                     'thumbnail': r're:^https://cdn\.[^\.]+\.steamstatic\.com',
-                    'n_entries': 2,
                 }
             },
             {
@@ -39,9 +39,7 @@ class SteamIE(InfoExtractor):
                     'id': '2040428',
                     'ext': 'mp4',
                     'title': 'Terraria video 2040428',
-                    'playlist_index': 2,
                     'thumbnail': r're:^https://cdn\.[^\.]+\.steamstatic\.com',
-                    'n_entries': 2,
                 }
             }
         ],
@@ -55,12 +53,10 @@ class SteamIE(InfoExtractor):
     }, {
         'url': 'https://store.steampowered.com/app/271590/Grand_Theft_Auto_V/',
         'info_dict': {
-            'id': '256757115',
-            'title': 'Grand Theft Auto V video 256757115',
-            'ext': 'mp4',
-            'thumbnail': r're:^https://cdn\.[^\.]+\.steamstatic\.com',
-            'n_entries': 20,
+            'id': '271590',
+            'title': 'Grand Theft Auto V',
         },
+        'playlist_count': 23,
     }]
 
     def _real_extract(self, url):
@@ -109,7 +105,6 @@ class SteamIE(InfoExtractor):
                                 'format_id': ext + quality,
                                 'url': video_url,
                             })
-            self._sort_formats(formats)
             entry['formats'] = formats
             entries.append(entry)
         embedded_videos = re.findall(r'(<iframe[^>]+>)', webpage)
@@ -137,7 +132,7 @@ class SteamCommunityBroadcastIE(InfoExtractor):
             'id': '76561199073851486',
             'title': r're:Steam Community :: pepperm!nt :: Broadcast 2022-06-26 \d{2}:\d{2}',
             'ext': 'mp4',
-            'uploader_id': 1113585758,
+            'uploader_id': '1113585758',
             'uploader': 'pepperm!nt',
             'live_status': 'is_live',
         },
@@ -163,14 +158,13 @@ class SteamCommunityBroadcastIE(InfoExtractor):
             'https://steamcommunity.com/actions/ajaxresolveusers',
             video_id, query={'steamids': video_id})[0]
 
-        self._sort_formats(formats)
         return {
             'id': video_id,
-            'title': self._html_extract_title(webpage) or self._og_search_title(webpage),
+            'title': self._generic_title('', webpage),
             'formats': formats,
             'live_status': 'is_live',
             'view_count': json_data.get('num_view'),
             'uploader': uploader_json.get('persona_name'),
-            'uploader_id': uploader_json.get('accountid'),
+            'uploader_id': str_or_none(uploader_json.get('accountid')),
             'subtitles': subs,
         }
