@@ -1,7 +1,7 @@
 import os
-import shutil
 
 from .common import PostProcessor
+from ..compat import shutil
 from ..utils import (
     PostProcessingError,
     decodeFilename,
